import QtConfigurator.Forms
import XSLForms.Prepare
import factory
import qtui
import os

class Configurator(QtConfigurator.Forms.Configurator):

    resource_dir = os.path.join(os.path.split(__file__)[0], "Resources")
    ui_filename = os.path.join(resource_dir, "config.ui")
    ui_hard_disks_filename = os.path.join(resource_dir, "config_hard_disks.ui")
    ui_memory_units_filename = os.path.join(resource_dir, "config_memory_units.ui")
    ui_storage_units_filename = os.path.join(resource_dir, "config_storage_units.ui")

    def __init__(self, *args, **kw):
        QtConfigurator.Forms.Configurator.__init__(self, *args, **kw)
        self.factory = factory.Factory(self.ui_filename)
        XSLForms.Prepare.ensure_qt_fragment(self.ui_filename, self.ui_hard_disks_filename, "hard_disks")
        XSLForms.Prepare.ensure_qt_fragment(self.ui_filename, self.ui_memory_units_filename, "memory_units")
        XSLForms.Prepare.ensure_qt_fragment(self.ui_filename, self.ui_storage_units_filename, "storage_units")

    def baseSystemChanged(self):
        print self.base_system.currentItem()

    def addHardDisk(self):
        hard_disks = qtui.QWidgetFactory.create(self.ui_hard_disks_filename)
        tab_pages = hard_disks.child("tab pages")
        tab = tab_pages.child("tab")
        self.hard_disks.addTab(tab, hard_disks.tabLabel(tab))
        self.factory.connect(tab, self)

    def addMemoryUnit(self):
        memory_units = qtui.QWidgetFactory.create(self.ui_memory_units_filename)
        tab_pages = memory_units.child("tab pages")
        tab = tab_pages.child("tab")
        self.memory_units.addTab(tab, memory_units.tabLabel(tab))
        self.factory.connect(tab, self)

    def addStorageUnit(self):
        storage_units = qtui.QWidgetFactory.create(self.ui_storage_units_filename)
        tab_pages = storage_units.child("tab pages")
        tab = tab_pages.child("tab")
        self.storage_units.addTab(tab, storage_units.tabLabel(tab))
        self.factory.connect(tab, self)

    def removeHardDisk(self):
        page = self.hard_disks.currentPage()
        self.hard_disks.removePage(page)
        page.deleteLater()

    def removeMemoryUnit(self):
        page = self.memory_units.currentPage()
        self.memory_units.removePage(page)
        page.deleteLater()

    def removeStorageUnit(self):
        page = self.storage_units.currentPage()
        self.storage_units.removePage(page)
        page.deleteLater()

    def updateConfig(self):
        print "configuration.updateConfig(): Not implemented yet"

    def exportConfig(self):
        print "configuration.exportConfig(): Not implemented yet"

# vim: tabstop=4 expandtab shiftwidth=4
